const { last } = require('lodash')

const {
  User,
  Email,
  services,
  Fragment,
} = require('pubsweet-component-helper-service')

const { sendInvitedHEEmail, sendEiCEmail } = require('./helpers')

module.exports = {
  async sendNotifications({
    reason,
    baseUrl,
    invitedHE,
    collection,
    isEiC = false,
    isCanceled = false,
    isAccepted = false,
    models: { User: UserModel, Fragment: FragmentModel },
  }) {
    const fragmentId = last(collection.fragments)
    const fragment = await FragmentModel.find(fragmentId)
    const fragmentHelper = new Fragment({ fragment })
    const { title } = await fragmentHelper.getFragmentData()
    const { submittingAuthor } = await fragmentHelper.getAuthorData({
      UserModel,
    })

    const titleText = `the manuscript titled "${title}" by ${
      submittingAuthor.firstName
    } ${submittingAuthor.lastName}`

    const userHelper = new User({ UserModel })
    const eics = await userHelper.getEditorsInChief()
    const eic = eics[0]
    const eicName = `${eic.firstName} ${eic.lastName}`
    const { customId } = collection

    const email = new Email({
      type: 'user',
      content: {
        signatureName: eicName,
        ctaLink: services.createUrl(
          baseUrl,
          `/projects/${collection.id}/versions/${fragment.id}/details`,
        ),
        ctaText: 'MANUSCRIPT DETAILS',
      },
    })

    if (isEiC) {
      sendInvitedHEEmail({
        email,
        baseUrl,
        eicName,
        customId,
        titleText,
        isCanceled,
        handlingEditor: invitedHE,
      })
    } else {
      sendEiCEmail({
        eic,
        email,
        baseUrl,
        customId,
        titleText,
        isAccepted,
        comments: reason ? `Reason: "${reason}"` : '',
        targetUserName: `${invitedHE.lastName}`,
      })
    }
  },
}
