const {
  services,
  Invitation,
  authsome: authsomeHelper,
} = require('pubsweet-component-helper-service')

const notifications = require('./emails/notifications')

module.exports = models => async (req, res) => {
  const { collectionId, invitationId, fragmentId } = req.params
  const { invitationToken } = req.body

  if (!services.checkForUndefinedParams(invitationToken))
    return res.status(400).json({ error: 'Token is required' })

  const UserModel = models.User
  try {
    const user = await UserModel.findOneByField(
      'invitationToken',
      invitationToken,
    )
    const collection = await models.Collection.find(collectionId)
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Fragment ${fragmentId} does not match collection ${collectionId}`,
      })
    const fragment = await models.Fragment.find(fragmentId)
    fragment.invitations = fragment.invitations || []
    const invitation = await fragment.invitations.find(
      invitation => invitation.id === invitationId,
    )

    const invitationHelper = new Invitation({
      userId: user.id,
      role: 'reviewer',
      invitation,
    })

    const invitationValidation = invitationHelper.validateInvitation()
    if (invitationValidation.error)
      return res.status(invitationValidation.status).json({
        error: invitationValidation.error,
      })

    const authsome = authsomeHelper.getAuthsome(models)
    const canPatch = await authsome.can(req.user, 'PATCH', invitation)
    if (!canPatch)
      return res.status(403).json({
        error: 'Unauthorized.',
      })

    invitation.respondedOn = Date.now()
    invitation.hasAnswer = true
    invitation.isAccepted = false
    await fragment.save()

    const baseUrl = services.getBaseUrl(req)

    notifications.sendNotifications({
      baseUrl,
      fragment,
      collection,
      reviewer: user,
      UserModel: models.User,
      emailType: 'reviewer-declined',
    })

    return res.status(200).json({})
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
